import { Float, ReadonlyMat2, Mat2, Vec2, ReadonlyMat3 } from '@andykswong/munum-types';
/**
 * Create a new identity {@link Mat2}.
 * @returns identity Mat2
 */
export declare function create(): Mat2;
/**
 * Set a {@link Mat2} to identity.
 * @returns out = I2
 */
export declare function id(out: Mat2): Mat2;
/**
 * Create a {@link Mat2} from {@link ReadonlyMat3}.
 * @returns identity Mat2
 */
export declare function fromMat3(m: ReadonlyMat3, out?: Mat2): Mat2;
/**
 * Copy a {@link Mat2}.
 * @returns out
 */
export declare const copy: (v: readonly [m11: number, m21: number, m12: number, m22: number], out?: Mat2) => Mat2;
/**
 * Sum 2 {@link Mat2}.
 * @returns out = a + b
 */
export declare const add: (a: readonly [m11: number, m21: number, m12: number, m22: number], b: readonly [m11: number, m21: number, m12: number, m22: number], out?: Mat2) => Mat2;
/**
 * Subtract 2 {@link Mat2}.
 * @returns out = a - b
 */
export declare const sub: (a: readonly [m11: number, m21: number, m12: number, m22: number], b: readonly [m11: number, m21: number, m12: number, m22: number], out?: Mat2) => Mat2;
/**
 * Multiply a {@link Mat2} by a constant.
 * @returns out = s * M
 */
export declare const scale: (m: readonly [m11: number, m21: number, m12: number, m22: number], s: Float, out?: Mat2) => Mat2;
/**
 * Transpose a {@link Mat2}.
 * @returns [M]T
 */
export declare const tr: (m: readonly [m11: number, m21: number, m12: number, m22: number], out?: Mat2) => Mat2;
/**
 * Multiply 2 {@link Mat2}.
 * @returns out = a * b
 */
export declare const mul: (a: readonly [m11: number, m21: number, m12: number, m22: number], b: readonly [m11: number, m21: number, m12: number, m22: number], out?: Mat2) => Mat2;
/**
 * Multiply a {@link Mat2} with a {@link Vec2}.
 * @returns out = m * v
 */
export declare const vmul: (a: readonly [m11: number, m21: number, m12: number, m22: number], b: readonly [x: number, y: number], out?: Vec2) => Vec2;
/**
 * Calculate the determinant of a {@link Mat2}.
 */
export declare function det(m: ReadonlyMat2): Float;
/**
 * Returns inverse of a {@link Mat2}, or null if matrix is not invertible.
 * @param a input matrix
 * @param out output matrix
 * @returns out = M^-1, or null if matrix is not invertible
 */
export declare function invert(a: ReadonlyMat2, out?: Mat2): Mat2 | null;
//# sourceMappingURL=mat2.d.ts.map