import { Float, ReadonlyVec2, Vec2 } from '@andykswong/munum-types';
/**
 * Create a new {@link Vec2}.
 * @param x defaults to 0
 * @param y defaults to 0
 * @returns [x, y]
 */
export declare function create(x?: Float, y?: Float): Vec2;
/**
 * Copy a {@link Vec2}.
 * @returns out
 */
export declare const copy: (v: readonly [x: number, y: number], out?: Vec2) => Vec2;
/**
 * Sum 2 {@link Vec2}.
 * @returns out = a + b
 */
export declare const add: (a: readonly [x: number, y: number], b: readonly [x: number, y: number], out?: Vec2) => Vec2;
/**
 * Subtract 2 {@link Vec2}.
 * @returns out = a - b
 */
export declare const sub: (a: readonly [x: number, y: number], b: readonly [x: number, y: number], out?: Vec2) => Vec2;
/**
 * Multiply a {@link Vec2} by a constant.
 * @returns out = s * v
 */
export declare const scale: (v: readonly [x: number, y: number], s: Float, out?: Vec2) => Vec2;
/**
 * Multiply 2 {@link Vec2} component-wise.
 * @returns out = a * b
 */
export declare const mul: (v: readonly [x: number, y: number], s: readonly [x: number, y: number], out?: Vec2) => Vec2;
/**
 * Calculate the dot product of 2 {@link Vec2}.
 * @returns a * b
 */
export declare const dot: (a: ReadonlyVec2, b: ReadonlyVec2) => Float;
/**
 * Linear interpolate 2 {@link Vec2}.
 * @returns out = lerp(a, b, t)
 */
export declare const lerp: (a: readonly [x: number, y: number], b: readonly [x: number, y: number], t: Float, out?: Vec2) => Vec2;
/**
 * Calculate squared length of a {@link Vec2}.
 * @returns dot(v, v)
 */
export declare const len2: (v: readonly [x: number, y: number]) => Float;
/**
 * Calculate length of a {@link Vec2}.
 * @returns |v|
 */
export declare const len: (v: readonly [x: number, y: number]) => Float;
/**
 * Normalize a {@link Vec2} and optionally stores result to the out param.
 * @returns v/|v|
 */
export declare const norm: (v: readonly [x: number, y: number], out?: Vec2) => Vec2;
//# sourceMappingURL=vec2.d.ts.map