import { Float, ReadonlyVec3, Vec3 } from '@andykswong/munum-types';
/**
 * Create a new {@link Vec3}.
 * @param x defaults to 0
 * @param y defaults to 0
 * @param z defaults to 0
 * @returns [x, y, z]
 */
export declare function create(x?: Float, y?: Float, z?: Float): Vec3;
/**
 * Copy a {@link Vec3}.
 * @returns out
 */
export declare const copy: (v: readonly [x: number, y: number, z: number], out?: Vec3) => Vec3;
/**
 * Sum 2 {@link Vec3}.
 * @returns out = a + b
 */
export declare const add: (a: readonly [x: number, y: number, z: number], b: readonly [x: number, y: number, z: number], out?: Vec3) => Vec3;
/**
 * Subtract 2 {@link Vec3}.
 * @returns out = a - b
 */
export declare const sub: (a: readonly [x: number, y: number, z: number], b: readonly [x: number, y: number, z: number], out?: Vec3) => Vec3;
/**
 * Multiply a {@link Vec3} by a constant.
 * @returns out = s * v
 */
export declare const scale: (v: readonly [x: number, y: number, z: number], s: Float, out?: Vec3) => Vec3;
/**
 * Multiply 2 {@link Vec3} component-wise.
 * @returns out = a * b
 */
export declare const mul: (v: readonly [x: number, y: number, z: number], s: readonly [x: number, y: number, z: number], out?: Vec3) => Vec3;
/**
 * Calculate the dot product of 2 {@link Vec3}.
 * @returns a * b
 */
export declare const dot: (a: ReadonlyVec3, b: ReadonlyVec3) => Float;
/**
 * Linear interpolate 2 {@link Vec3}.
 * @returns out = lerp(a, b, t)
 */
export declare const lerp: (a: readonly [x: number, y: number, z: number], b: readonly [x: number, y: number, z: number], t: Float, out?: Vec3) => Vec3;
/**
 * Calculate squared length of a {@link Vec3}.
 * @returns dot(v, v)
 */
export declare const len2: (v: readonly [x: number, y: number, z: number]) => Float;
/**
 * Calculate length of a {@link Vec3}.
 * @returns |v|
 */
export declare const len: (v: readonly [x: number, y: number, z: number]) => Float;
/**
 * Normalize a {@link Vec3} and optionally stores result to the out param.
 * @returns v/|v|
 */
export declare const norm: (v: readonly [x: number, y: number, z: number], out?: Vec3) => Vec3;
/**
 * Calculate cross product of 2 {@link Vec3}.
 * @returns out = a x b
 */
export declare function cross(a: ReadonlyVec3, b: ReadonlyVec3, out?: Vec3): Vec3;
//# sourceMappingURL=vec3.d.ts.map