import { Float, ReadonlyVec3, ReadonlyVec4, Vec4 } from '@andykswong/munum-types';
/**
 * Create a new {@link Vec4}.
 * @param x defaults to 0
 * @param y defaults to 0
 * @param z defaults to 0
 * @param w defaults to 0
 * @returns [x, y, z, w]
 */
export declare function create(x?: Float, y?: Float, z?: Float, w?: Float): Vec4;
/**
 * Create a {@link Vec4} from {@link ReadonlyVec3}.
 * @param v Vec3
 * @param out output Vec4
 * @returns [v[0], v[1], v[2], w]
 */
export declare function fromVec3(v: ReadonlyVec3, out?: Vec4): Vec4;
/**
 * Copy a {@link Vec4}.
 * @returns out
 */
export declare const copy: (v: readonly [x: number, y: number, z: number, w: number], out?: Vec4) => Vec4;
/**
 * Sum 2 {@link Vec4}.
 * @returns out = a + b
 */
export declare const add: (a: readonly [x: number, y: number, z: number, w: number], b: readonly [x: number, y: number, z: number, w: number], out?: Vec4) => Vec4;
/**
 * Subtract 2 {@link Vec4}.
 * @returns out = a - b
 */
export declare const sub: (a: readonly [x: number, y: number, z: number, w: number], b: readonly [x: number, y: number, z: number, w: number], out?: Vec4) => Vec4;
/**
 * Multiply a {@link Vec4} by a constant.
 * @returns out = s * v
 */
export declare const scale: (v: readonly [x: number, y: number, z: number, w: number], s: Float, out?: Vec4) => Vec4;
/**
 * Multiply 2 {@link Vec4} component-wise.
 * @returns out = a * b
 */
export declare const mul: (v: readonly [x: number, y: number, z: number, w: number], s: readonly [x: number, y: number, z: number, w: number], out?: Vec4) => Vec4;
/**
 * Calculate the dot product of 2 {@link Vec4}.
 * @returns a * b
 */
export declare const dot: (a: ReadonlyVec4, b: ReadonlyVec4) => Float;
/**
 * Linear interpolate 2 {@link Vec4}.
 * @returns out = lerp(a, b, t)
 */
export declare const lerp: (a: readonly [x: number, y: number, z: number, w: number], b: readonly [x: number, y: number, z: number, w: number], t: Float, out?: Vec4) => Vec4;
/**
 * Calculate squared length of a {@link Vec4}.
 * @returns dot(v, v)
 */
export declare const len2: (v: readonly [x: number, y: number, z: number, w: number]) => Float;
/**
 * Calculate length of a {@link Vec4}.
 * @returns |v|
 */
export declare const len: (v: readonly [x: number, y: number, z: number, w: number]) => Float;
/**
 * Normalize a {@link Vec4} and optionally stores result to the out param.
 * @returns v/|v|
 */
export declare const norm: (v: readonly [x: number, y: number, z: number, w: number], out?: Vec4) => Vec4;
//# sourceMappingURL=vec4.d.ts.map